# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if 0%{?fedora}
  %bcond_without unit_tests
%endif
%if 0%{?rhel}
  %bcond_with unit_tests
%endif
%if 0%{?suse_version}
  %if 0%{?suse_version} > 1320
    #openSUSE Factory
    %bcond_without unit_tests
  %else
    %if 0%{?suse_version} == 1315
      #SLE12 or openSUSE LEAP
      %if 0%{?sle_version} == 120200
        # openSUSE LEAP 42.2
        %bcond_with unit_tests
      %else
        #SLE12 does not have deps
        %bcond_with unit_tests
      %endif
    %else
      # Older SUSE release
      %bcond_with unit_tests    
    %endif
  %endif
%endif

%if ! (0%{?fedora} > 12 || 0%{?rhel} > 5)
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%endif

Name:           python-ceph-cfg
Version:        0.2.3+git.1478902462.f898834
Release:        2.1
Summary:        Python library to Admin and deploy Ceph
License:        Apache-2.0
Group:          System/Filesystems
Url:            https://github.com/ceph/ceph-deploy
Source0:        %{name}-%{version}.tar.xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArchitectures: noarch
BuildRequires:  python-devel
BuildRequires:  python-setuptools
%if 0%{?suse_version}
BuildRequires:  python-base
%endif
%if 0%{with unit_tests}
BuildRequires:  python-virtualenv
BuildRequires:  python-tox
BuildRequires:  python-pip
BuildRequires:  python-flake8
BuildRequires:  python-pip
BuildRequires:  python-pyflakes
BuildRequires:  python-mock
BuildRequires:  python-coverage
%if 0%{?suse_version}
BuildRequires:  python-pytest >= 2.1.3
%endif
%if (0%{?fedora} > 12 || 0%{?rhel} > 5)
BuildRequires:  pytest
%endif
%endif
Requires:  parted
Requires:  gptfdisk
Requires:  util-linux

%description
An easy to use library to make tools to admin and deploy ceph storage clusters.
Ceph is a distributed network storage service. This library is used by salt-ceph
to configure ceph.

%prep
%setup -q

# Pre-populate the directory so that this step is avoided.
%setup -q -T -D -n %{name}-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
%if 0%{with unit_tests}
# Call the unit tests directly as OBS blocks internet connection for builds
# python setup.py test
py.test
flake8 --select=F,E9 ceph_cfg
%endif

%files
%defattr(-,root,root,-)
%doc LICENSE README.md
%{python_sitelib}/*

%changelog
* Fri Nov 11 2016 osynge@suse.com
- Updated to version 0.2.3
  * Better error reporting when failing to communicate with the
    cluster.
  * Handle configuration files with no sections correctly.
  * Better python3 compliance.
  * More unit tests.
* Fri Sep  9 2016 osynge@suse.com
- Updated to version 0.2.0.
  * Bugfix with mon_status.
  * Generate junit test results when running tox by default.
* Thu Sep  8 2016 UTC 2016 - osynge@suse.com
- Updated to version 0.2.0.
  * bnc#994637
  * Add new mon methods to allow life cycling mon roles.
    + mon_destroy
    + mon_list
  * API change for mon methods require mon_name argument.
    + mon_is
    + mon_status
    + mon_quorum
    + mon_active
    + mon_create
* Mon Sep  5 2016 osynge@suse.com
- Updated to version 0.1.9.
  * OSD reweight method.
    + Useful for remote rebalancing of the cluster.
    + Useful for gracefully decomisoning an OSD when set to 0 weight.
  * Added cephfs methods
    + cephfs_ls
    + cephfs_add
  - bnc#983971
    + cephfs_del
  - bnc#994602
  * Dont run unit tests on SLE12 builds of the rpm
    + Due to packages not being available.
* Wed Aug 17 2016 osynge@suse.com
- Updated to version 0.1.8.
  * python 3.4 tox support for unit tests.
    + Now runs unit tests in python 2.7 and 3.4
  * When called by salt fix exception in utils_which.
    + should provide useful diagnostic message.
    + bnc#994056
  * Avoid side effect of not being mon node.
  * Merge improvements to mon_members_refresh.
    + Remove side effect of not being a mon node.
    + Added tests for ceph_cfg.mdl_updater.mon_members_refresh.
    + Fix error message "section error" which was misleading.
    + bnc#993468
* Wed Jul 13 2016 osynge@suse.com
- Updated to version 0.1.7
  * Refactor rgw and mds to use common class to manage service keys.
  * Add central constant for timeouts and use it where applicable.
    + Change default timeout to 20 seconds.
    + bnc#988418
  * Fix permissions on mds and rgw service keys.
    + bnc#982290
  * Enable mon daemons on boot.
    + bnc#983254
* Mon Jul 11 2016 osynge@suse.com
- Updated to version 0.1.6
  * Added ceph config file parser with tests.
    + bnc#983474
* Wed Jul  6 2016 osynge@suse.com
- Added run time dependences on:
  * parted
  * gptfdisk
  * util-linux
    + bnc#982536
* Wed Jul  6 2016 osynge@suse.com
- Fixed purge function.
  * bnc#987582
- Fixed handling of floppy disks on target clusters
  * bnc#982536
- Added new discover fields for disks and partitions.
  * disk
    + 'DRIVER',
    + 'SECTOR_SIZE_LOGICAL',
    + 'SECTOR_SIZE_PHYSICAL',
    + 'TABLE',
    + 'VENDOR_NAME'
  * partition
    + 'NUMBER',
    + 'SIZE_HUMAN'
  * bnc#982548
- Added test for lsblk version.
- Added test for lsblk parsing
- Added test for parted parsing
* Mon May 30 2016 osynge@suse.com
- Updated to version 0.1.4
  * Remove nose test from setup.py
* Mon May 30 2016 osynge@suse.com
- Updated to version 0.1.3
  * Add flake8 and py.test infrastructure
  * rgw: do not check for missing pools.
    + RGW pools have different names on Jewel.
    + these pools are autocreated in Jewel.
    + Creating pools which are not used for the 2 reasons above only increases pg's/pgp's per osd.
    + Multisite/Multizone does probably not need these standard rgw pools.
* Wed May 11 2016 osynge@suse.com
- Updated to version 0.1.2
  * memoize the paths for executables only when they are found
  - bnc#979398
* Wed May 11 2016 osynge@suse.com
- Updated to version 0.1.1
  * Raise exceptions when CLI tools are missing
  - bnc#979321
* Wed Apr 27 2016 osynge@suse.com
- Fixed license in the rpm to match the code.
- Improved rpm metadata description.
* Tue Apr 26 2016 osynge@suse.com
- Updated to version 0.1.0
  * Change code base to a library.
  * Check for mds rgw commands
* Wed Apr 20 2016 osynge@suse.com
- If the boot strap mon directory is missing create it.
* Fri Apr 15 2016 osynge@suse.com
- Initial version
